@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import BaseModel, Field
 
 from pipelex.cogt.llm.llm_report import LLMTokensUsage
@@ -11,8 +9,8 @@ from pipelex.cogt.llm.llm_report import LLMTokensUsage
 
 class LLMJobParams(BaseModel):
     temperature: float = Field(..., ge=0, le=1)
-    max_tokens: Optional[int] = Field(None, gt=0)
-    seed: Optional[int] = Field(None, ge=0)
+    max_tokens: int | None = Field(None, gt=0)
+    seed: int | None = Field(None, ge=0)
 
 
 class LLMJobConfig(BaseModel):
@@ -26,4 +24,4 @@ class LLMJobConfig(BaseModel):
 
 
 class LLMJobReport(BaseModel):
-    llm_tokens_usage: Optional[LLMTokensUsage] = None
+    llm_tokens_usage: LLMTokensUsage | None = None
