@@ -1,14 +1,16 @@
-from typing import Dict, Optional
-
 from pydantic import Field, RootModel
 from typing_extensions import override
 
-from pipelex.exceptions import PipelineManagerNotFoundError
+from pipelex.base_exceptions import PipelexException
 from pipelex.pipeline.pipeline import Pipeline
 from pipelex.pipeline.pipeline_factory import PipelineFactory
 from pipelex.pipeline.pipeline_manager_abstract import PipelineManagerAbstract
 
-PipelineManagerRoot = Dict[str, Pipeline]
+PipelineManagerRoot = dict[str, Pipeline]
+
+
+class PipelineManagerNotFoundError(PipelexException):
+    pass
 
 
 class PipelineManager(PipelineManagerAbstract, RootModel[PipelineManagerRoot]):
@@ -23,14 +25,15 @@ class PipelineManager(PipelineManagerAbstract, RootModel[PipelineManagerRoot]):
         self.root.clear()
 
     @override
-    def get_optional_pipeline(self, pipeline_run_id: str) -> Optional[Pipeline]:
+    def get_optional_pipeline(self, pipeline_run_id: str) -> Pipeline | None:
         return self.root.get(pipeline_run_id)
 
     @override
     def get_pipeline(self, pipeline_run_id: str) -> Pipeline:
         pipeline = self.get_optional_pipeline(pipeline_run_id=pipeline_run_id)
         if pipeline is None:
-            raise PipelineManagerNotFoundError(f"Pipeline {pipeline_run_id} not found")
+            msg = f"Pipeline {pipeline_run_id} not found"
+            raise PipelineManagerNotFoundError(msg)
         return pipeline
 
     def _set_pipeline(self, pipeline_run_id: str, pipeline: Pipeline) -> Pipeline:
