@@ -1,5 +1,4 @@
 from abc import ABC, abstractmethod
-from typing import Optional
 
 LATEST_SECRET_VERSION_NAME = "latest"
 
@@ -9,13 +8,13 @@ class SecretsProviderAbstract(ABC):
     def get_required_secret(self, secret_id: str) -> str: ...
 
     @abstractmethod
-    def get_optional_secret(self, secret_id: str) -> Optional[str]: ...
+    def get_optional_secret(self, secret_id: str) -> str | None: ...
 
     @abstractmethod
     def get_required_secret_specific_version(self, secret_id: str, version_id: str) -> str: ...
 
     @abstractmethod
-    def get_optional_secret_specific_version(self, secret_id: str, version_id: str) -> Optional[str]: ...
+    def get_optional_secret_specific_version(self, secret_id: str, version_id: str) -> str | None: ...
 
     @abstractmethod
     def set_secret_as_env_var(self, secret_id: str, version_id: str = LATEST_SECRET_VERSION_NAME): ...
